
% Script AlPassengerCars_Compute.m
%
% Dynamic MFA model for Al content of car stock
%
% Pratulya Sivashankar, 2012
%

% Load saved data so that it does not have to be read again from Excel

clc
load('modeldata.mat');

% Running the main section for all the scenarios:

for s = 1:NoofScenarios
    
    %% %%%%%%%%% Setting the Scenarios Parameters %%%%%%%%%%%%%%
    if scenarios(s,1) == 1
        Population    = PopulationScenario(:,1);
    elseif scenarios(s,1) == 2
        Population = PopulationScenario(:,2);
    else
        Population = PopulationScenario(:,3);
    end
    
    if scenarios(s,2) == 1
        Lifetime    = LifetimeScenario(:,1);
    elseif scenarios(s,2) == 2
        Lifetime = LifetimeScenario(:,2);
    else
        Lifetime = LifetimeScenario(:,3);
    end
    
    if scenarios(s,3) == 1
        Kilometrage    = KilometrageScenario(:,1);
    elseif scenarios(s,3) == 2
        Kilometrage = KilometrageScenario(:,2);
    else
        Kilometrage = KilometrageScenario(:,3);
    end
    
    if scenarios(s,4) == 1
        CarsPerCapita    = CarsPerCapitaScenario(:,1);
    elseif scenarios(s,4) == 2
        CarsPerCapita = CarsPerCapitaScenario(:,2);
    else
        CarsPerCapita = CarsPerCapitaScenario(:,3);
    end
    
    if scenarios(s,5) == 1
        Fuel_eff    = Fuel_eff_Scenario(:,1);
    elseif scenarios(s,5) == 2
        Fuel_eff = Fuel_eff_Scenario(:,2);
    else
        Fuel_eff = Fuel_eff_Scenario(:,3);
    end
    
    if scenarios(s,6) == 1
        Al_Cast_recy_per = Al_Cast_recy_per_Scenario(:,2);
    else
        Al_Cast_recy_per = Al_Cast_recy_per_Scenario(:,1);
    end
    
    if scenarios(s,7) == 1
        Al_Wrought_recy_per = Al_Wrought_recy_per_Scenario(:,2);
    else
        Al_Wrought_recy_per = Al_Wrought_recy_per_Scenario(:,1);
    end
    
    if scenarios(s,8) == 1
        Steel_recy_per = Steel_recy_per_Scenario(:,2);
    else
        Steel_recy_per = Steel_recy_per_Scenario(:,1);
    end
    
    if scenarios(s,9) == 1
        Al_Wrought_tot = Al_Wrought_tot_Scenario(:,2);
    elseif scenarios(s,9) == 2
        Al_Wrought_tot = Al_Wrought_tot_Scenario(:,1);
    else
        Al_Wrought_tot = Al_Wrought_tot_Scenario(:,3);
    end
    
    if scenarios(s,10) == 1
        Al_Cast_tot = Al_Cast_tot_Scenario(:,2);
    else
        Al_Cast_tot = Al_Cast_tot_Scenario(:,1);
    end
    
    %% %%%%%%%%%%%%%%%%%% Substituting the excess Steel with Al %%%%%%%%%
    
    % The reference values are obtained from the IAI report - Improving
    % Sustainability in the Transport Sector.
    
    % The substitution for Cast Al is done with the reference values for 
    % the car's engine component.
    
    % The substitution for Wrought Al is done with the reference values for
    % the car's BIW.
    
    % In both cases, there is an indirect weight saving of 23%
    Ref_Engine_Cast = 16.4; %kg
    Ref_Engine_Steel = 31; %kg
    Ref_BIW_Wrought = 295; %kg
    Ref_BIW_Steel = 475; %kg
    Indirect_Savings = .23;
    
    % Finding the ratio of the amount of reference Al to the total savings
    % from lightweighting:
    Cast_Direct_Savings = Ref_Engine_Steel - Ref_Engine_Cast;
    Tot_Cast_Savings = Cast_Direct_Savings * (1 + Indirect_Savings);
    Cast_to_Tot_Savings = Ref_Engine_Cast/Tot_Cast_Savings;  
    
    Wrought_Direct_Savings = Ref_BIW_Steel - Ref_BIW_Wrought;
    Tot_Wrought_Savings = Wrought_Direct_Savings * (1 + Indirect_Savings);
    Wrought_to_Tot_Savings = Ref_BIW_Wrought/Tot_Wrought_Savings; 
    
    % Performing the substitution: Finding the savings from Cast and
    % Wrought Al and then modifying the amount of Steel in the car
    for i = 1:41
        
        Cast_diff(i) = Al_Cast_tot(60+i) - Al_Cast_tot(60);
        Steel_diff_Cast(i) = Cast_diff(i)/Cast_to_Tot_Savings;
                
        Wrought_diff(i) = Al_Wrought_tot(60+i) - Al_Wrought_tot(60);
        Steel_diff_Wrought(i) = Wrought_diff(i)/Wrought_to_Tot_Savings;
        
        % The first 2 subtaction terms represent the savings while the last
        % 2 terms represent the actual steel substituted with the Al
        Steel_tot(60+i) = Steel_tot(60) - Steel_diff_Cast(i) - Steel_diff_Wrought(i) - Cast_diff(i) - Wrought_diff(i);
        
    end
    
    %% Finding the total car stock
    
    TotalCarStock =Population .* (CarsPerCapita/1000) ;
    
       
    
    % Now, we have to calculate the in-and outflows to the car stock, given the
    % lifetime of the cars. This is done by calling the function
    % CalculateFullStock_Normal_DetailedWaste, which was developed by
    % Stefan Pauliuk
    
    
    [DetailedCarStock,CarsBought,CarsToWaste,StockChange,DetailedCarsToWaste] = CalculateFullStock_Normal_DetailedWaste(TotalCarStock,Lifetime,0.3*Lifetime);
    
    %4.Now we want to calculate amount of aluminium, steel and energy associated in Cars
    %inflows and outflows, in terms of Wrought and Cast Al, Steel and Direct and Indirect energy.
    
    
    %% %%%%%%%%%%%%%%%%%% Aluminium %%%%%%%%%%%%%%%%%%%
    Castinginflow = CarsBought .* Al_Cast_tot;
    DetailedCasteToWaste = DetailedCarsToWaste * diag(Al_Cast_tot);
    Castingoutflow = DetailedCasteToWaste * ones(Modellength,1);
    Wroughtinflow = CarsBought .* Al_Wrought_tot ;
    DetailedWroughtToWaste = DetailedCarsToWaste * diag(Al_Wrought_tot);
    Wroughtoutflow = DetailedWroughtToWaste * ones(Modellength,1);
    AlOutflow = Castingoutflow + Wroughtoutflow;
    
    
    SecCastinginflow = Castinginflow .* Al_Cast_recy_per ;
    SecWroughtinflow = Wroughtinflow .* Al_Wrought_recy_per;
    Tot_Sec_Inflow = SecCastinginflow + SecWroughtinflow;
    
    
    FlowM = AlOutflow * 0.9;  % to account for losses in EOL
    
    Altotal= Al_Cast_tot + Al_Wrought_tot;
    detailedAlstock = DetailedCarStock *diag(Altotal);
    Alstock = detailedAlstock * ones(Modellength,1);
    Alpercapita =Alstock / Population *ones(Modellength,1);
    
    %% %%%%%%%%%%%%%%%%%% Steel %%%%%%%%%%%%%%%%%%%%
    
    Steelinflow = CarsBought .* Steel_tot;
    DetailedSteelToWaste = DetailedCarsToWaste * diag(Steel_tot);
    Steeloutflow = DetailedSteelToWaste * ones (Modellength,1);
    
    SecSteelinflow = Steelinflow .* Steel_recy_per;
    
    FlowS = Steeloutflow * 0.9;  % to account for losses in EOL
    
    %% %%%%%%%%%%%%%%%%%% Energy %%%%%%%%%%%%%%%%%%%
    
    % Operation Phase:
    
    % The number of kilometres driven per year in a car is decreased per
    % year, compounded at -4% and the fuel consumption of the car is assumed
    % to increase by 1% each year. Both these assumptions account for the 
    % inefficiencies in the car.
    DynamicKilometrage = diag(Kilometrage);
    DynamicFuel_eff = diag(Fuel_eff);
    for i = 1:Modellength;
        for j = i+1:Modellength;
            DynamicKilometrage(j,i) = DynamicKilometrage(i,i)*0.96^(j-i);
            DynamicFuel_eff(j,i) = DynamicFuel_eff(i,i)*1.01^(j-i);
        end
    end
    
    DetailedKilometrage = DynamicKilometrage .* DetailedCarStock;
    DetailedOper_Energy = (DetailedKilometrage .* DynamicFuel_eff)/100 * Petrol_Energy;
    % FInding the total Operational Energy
    Eoper_tot = DetailedOper_Energy * ones(Modellength,1);
    
    %Production Phase:
    
    Eprod_Prim_Al_Wr = Al_Wrought_tot .* Al_Wrought_prim_ener .* (ones(Modellength,1) - Al_Wrought_recy_per) .* CarsBought;
    Eprod_Prim_Al_Ca = Al_Cast_tot .* Al_Cast_prim_ener .* (ones(Modellength,1) - Al_Cast_recy_per) .* CarsBought;
    Eprod_Sec_Al_Wr = Al_Wrought_tot .* Al_Wrought_sec_ener .* Al_Wrought_recy_per .* CarsBought;
    Eprod_Sec_Al_Ca = Al_Cast_tot .* Al_Cast_sec_ener .* Al_Cast_recy_per .* CarsBought;
    Eprod_Al_tot = Eprod_Prim_Al_Wr + Eprod_Prim_Al_Ca + Eprod_Sec_Al_Wr + Eprod_Sec_Al_Ca;
    
    Eprod_Prim_Steel = Steel_tot .* Steel_prim_ener .* (ones(Modellength,1) - Steel_recy_per) .* CarsBought;
    Eprod_Sec_Steel = Steel_tot .* Steel_sec_ener .* Steel_recy_per .* CarsBought;
    Eprod_Steel_tot = Eprod_Prim_Steel + Eprod_Sec_Steel;
    
    Eprod_tot = Eprod_Al_tot + Eprod_Steel_tot;
    
    %Combined:
    
    E_tot = Eoper_tot + Eprod_tot;
    
    
    %% %%%%%%%%%%%%%%%%%%%%% Emissions %%%%%%%%%%%%%%%%%%%%%%%%
    
    Detailed_Emissions_Oper = (DetailedKilometrage .* DynamicFuel_eff)/100 *  GWP_Petrol;
    Emissions_Oper = Detailed_Emissions_Oper * ones(Modellength,1);
    
    Emissions_Steel_prim = Steel_tot .* (ones(Modellength,1) - Steel_recy_per) .* CarsBought * GWP_Steel_prim;
    Emissions_Steel_sec = Steel_tot .* Steel_recy_per .* CarsBought * GWP_Steel_sec;
    Emissions_Steel = Emissions_Steel_prim + Emissions_Steel_sec;
    
    Emissions_Prim_Al_Wr = Al_Wrought_tot .* (ones(Modellength,1) - Al_Wrought_recy_per) .* CarsBought * GWP_Al_prim;
    Emissions_Prim_Al_Ca = Al_Cast_tot .* (ones(Modellength,1) - Al_Cast_recy_per) .* CarsBought * GWP_Al_prim;
    Emissions_Sec_Al_Wr = Al_Wrought_tot .* Al_Wrought_recy_per .* CarsBought * GWP_Al_sec;
    Emissions_Sec_Al_Ca = Al_Cast_tot .* Al_Cast_recy_per .* CarsBought * GWP_Al_sec;
    Emissions_Al = Emissions_Prim_Al_Wr + Emissions_Prim_Al_Ca + Emissions_Sec_Al_Wr + Emissions_Sec_Al_Ca;
    
    Emissions_Prod = Emissions_Steel + Emissions_Al;
    
    Emissions_tot = Emissions_Oper + Emissions_Prod;
    
    %% %%%%%%%%%%%%%%%%%%%%%% Graphs (My Favorite part!) %%%%%%%%%%%%%%
    %Plotting the Graphs
    
%     %Energy
%     plot(GlobalTime, Eprod_tot, GlobalTime, E_tot, GlobalTime, Eoper_tot,'LineWidth',2,'LineWidth',2,'LineWidth',2)
%     hold on;
%     grid on;
%     title('Yearly Energy Consumption');
%     xlabel('Year');
%     ylabel('Energy Consumption (MJ)');
%     set(gca,'Xtick', [1950 1960 1970 1980 1990 2000 2010 2020 2030 2040 2050]);
%     close gcf;
%     
%     %Emissions
%     figure;
%     plot(GlobalTime, Emissions_Prod, GlobalTime, Emissions_tot, GlobalTime, Emissions_Oper,'LineWidth',2,'LineWidth',2,'LineWidth',2)
%     hold on;
%     grid on;
%     title('Yearly Emissions (kg CO2 eq)');
%     xlabel('Year');
%     ylabel('Emissions (kg Co2 eq)');
%     set(gca,'Xtick', [1950 1960 1970 1980 1990 2000 2010 2020 2030 2040 2050]);
%     close gcf;
%     
%     %Al Flows
%     figure;
%     plot(GlobalTime,SecCastinginflow,GlobalTime,FlowM,'LineWidth',2,'LineWidth',2);
%     % Format plot:
%     hold on;
%     grid on;
%     axis([1950,2050,0,9.e10]);
%     set(gca,'Xtick', [1950 1960 1970 1980 1990 2000 2010 2020 2030 2040 2050]);
%     axis 'auto_x';
%     axis 'auto_y';
%     x_label = xlabel('Year');
%     set(x_label,'FontSize',18);
%     y_label = ylabel('Al flow');
%     set(y_label,'FontSize',14);
%     set(title('Global Al demand and supply'),'FontSize',14);
%     % save plot as png
%     print(gcf,'-dpng', '-r150',strcat(path,'HistCarStock_Global_Al.png'));
%     hold off;
%     disp('Graph has been successfully saved.<br>');
%     close gcf;
%     
%     %Steel Flows
%     figure;
%     plot(GlobalTime,SecSteelinflow,GlobalTime,FlowS,'LineWidth',2,'LineWidth',2);
%     % Format plot:
%     hold on;
%     grid on;
%     axis([1950,2050,0,9.e10]);
%     set(gca,'Xtick', [1950 1960 1970 1980 1990 2000 2010 2020 2030 2040 2050]);
%     axis 'auto_x';
%     axis 'auto_y';
%     x_label = xlabel('Year');
%     set(x_label,'FontSize',18);
%     y_label = ylabel('Steel flow');
%     set(y_label,'FontSize',14);
%     set(title('Global Steel demand and supply'),'FontSize',14);
%     % save plot as png
%     print(gcf,'-dpng', '-r150',strcat(path,'HistCarStock_Global_Steel.png'));
%     hold off;
%     disp('Graph has been successfully saved.<br>');
%     close gcf;
    
   
    
    
    %%   Save results from Workspace:
    disp('Export data as .mat-file.<br>');
    save(strcat(path,'Global.mat'));
    
    disp('Exporting data in Matlab style finished.<br>');
    
    
    
    
    % gather data:
    %Header:
    Header(1,1) = cellstr('Scenario');
    Header(2,1) = cellstr('Castingoutflow');
    Header(2,2) = cellstr('Wroughtoutflow');
    Header(2,3) = cellstr('Car inflow');
    Header(2,4) = cellstr('Car outflow');
    Header(2,5) = cellstr('casting inflow');
    Header(2,6) = cellstr('AlOutflow');
    Header(2,7) = cellstr('FlowM');
    Header(2,8) = cellstr('SecCastinginflow');
    Header(2,9) = cellstr('SecWroughtinflow');
    Header(2,10) = cellstr('Tot_Sec_Inflow');
    Header(2,11) = cellstr('Eoper_tot');
    Header(2,12) = cellstr('Eprod_Al_tot');
    Header(2,13) = cellstr('E_tot');
    Header(2,14) = cellstr('Steelinflow');
    Header(2,15) = cellstr('Steeloutflow');
    Header(2,16) = cellstr('SecSteelinflow');
    Header(2,17) = cellstr('Emissions_Oper');
    Header(2,18) = cellstr('Emissions_Steel');
    Header(2,19) = cellstr('Emissions_Al');
    Header(2,20) = cellstr('Emissions_tot');
    Header(2,21) = cellstr('Steel_tot');
    Header(2,22) = cellstr('FlowS');
    Header(2,23) = cellstr('Eprod_Steel_tot');
    
    
    %Body:
    Results(1:Modellength,1) = Castingoutflow;
    Results(1:Modellength,2) = Wroughtoutflow;
    Results(1:Modellength,3) = CarsBought;
    Results(1:Modellength,4) = CarsToWaste;
    Results(1:Modellength,5) = Castinginflow;
    Results(1:Modellength,6) = AlOutflow;
    Results(1:Modellength,7) = FlowM;
    Results(1:Modellength,8) = SecCastinginflow;
    Results(1:Modellength,9) = SecWroughtinflow;
    Results(1:Modellength,10) = Tot_Sec_Inflow;
    Results(1:Modellength,11) = Eoper_tot;
    Results(1:Modellength,12) = Eprod_Al_tot;
    Results(1:Modellength,13) = E_tot;
    Results(1:Modellength,14) = Steelinflow;
    Results(1:Modellength,15) = Steeloutflow;
    Results(1:Modellength,16) = SecSteelinflow;
    Results(1:Modellength,17) = Emissions_Oper;
    Results(1:Modellength,18) = Emissions_Steel;
    Results(1:Modellength,19) = Emissions_Al;
    Results(1:Modellength,20) = Emissions_tot;
    Results(1:Modellength,21) = Steel_tot;
    Results(1:Modellength,22) = FlowS;
    Results(1:Modellength,23) = Eprod_Steel_tot;
    
    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %   3) Write data:
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    
    xlswrite(resultfilename,Header,char(scenarionames(s)),'A1');
    xlswrite(resultfilename,Results,char(scenarionames(s)),'A3');
    
end

%Program succesfully run
fprintf('Model calculations have been finished successfully!!\n');
